@@ -4,11 +4,11 @@ use all4art_authservice_domain::{user::User, public_key::{PublicKey, self}, clea
 
 pub struct SubscribeCommand { 
     _public_key: PublicKey,
-    _clear_text_password: Arc<dyn ClearTextPassword>
+    _clear_text_password: Arc<dyn ClearTextPassword + Send + Sync>
 }
 
 impl SubscribeCommand {
-    pub fn new(public_key: PublicKey, clear_text_password: Arc<dyn ClearTextPassword>) -> Self { 
+    pub fn new(public_key: PublicKey, clear_text_password: Arc<dyn ClearTextPassword + Send + Sync>) -> Self { 
         SubscribeCommand{_public_key: public_key, _clear_text_password: clear_text_password} 
     }
 
